@@ -2,7 +2,7 @@ import sys
 from time import sleep
 from siwat_light_control_protocol.input_validation import validate_rgb
 from siwat_light_control_protocol.siwat_light_control_protocol_multi_serial import siwat_light_control_protocol_multi_serial as slcp
-import siwat_remote_light_control_protocol_server.led_effects as led_effects
+import siwat_light_control_protocol.led_effects as led_effects
 import threading
 import json
 import paho.mqtt.client as mqtt
@@ -178,6 +178,7 @@ def handle_mqtt_messages(client, userdata, msg: mqtt.MQTTMessage):
             report_state()
     except SerialException:
         print("Serial Disconnected, Exiting. . .")
+        mqttclient.disconnect()
         sys.exit(19)
 mqttclient.on_message = handle_mqtt_messages
 
